==> javie-0.3.1-src.tar.gz: javie-0.3.1-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/internal/services/AudioRenderContextProxy.java <==
/*
 * Copyright (c) 2009 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core.internal.services;

import ch.kuramo.javie.api.AudioMode;
import ch.kuramo.javie.core.services.AudioRenderContext;

public class AudioRenderContextProxy
		extends AbstractRenderContextProxy<AudioRenderContextImpl>
		implements AudioRenderContext {

	private static final ThreadLocal<AudioRenderContextImpl>
			_threadLocal = new ThreadLocal<AudioRenderContextImpl>();

	protected ThreadLocal<AudioRenderContextImpl> getThreadLocal() {
		return _threadLocal;
	}

	public AudioMode getAudioMode() {
		return getImpl().getAudioMode();
	}

	public void setAudioMode(AudioMode audioMode) {
		getImpl().setAudioMode(audioMode);
	}

	public int getFrameCount() {
		return getImpl().getFrameCount();
	}

	public void setFrameCount(int count) {
		getImpl().setFrameCount(count);
	}

}

==> javie-0.3.10-src.tar.gz: javie-0.3.10-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/internal/services/AudioRenderContextProxy.java <==
/*
 * Copyright (c) 2009,2010 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core.internal.services;

import ch.kuramo.javie.api.AudioMode;
import ch.kuramo.javie.core.services.AudioRenderContext;

public class AudioRenderContextProxy
		extends AbstractRenderContextProxy<AudioRenderContextImpl>
		implements AudioRenderContext {

	private static final ThreadLocal<AudioRenderContextImpl>
			_threadLocal = new ThreadLocal<AudioRenderContextImpl>();

	protected ThreadLocal<AudioRenderContextImpl> getThreadLocal() {
		return _threadLocal;
	}

	public AudioMode getAudioMode() {
		return getImpl().getAudioMode();
	}

	public void setAudioMode(AudioMode audioMode) {
		getImpl().setAudioMode(audioMode);
	}

	public int getFrameCount() {
		return getImpl().getFrameCount();
	}

	public void setFrameCount(int count) {
		getImpl().setFrameCount(count);
	}

	public int getEvaluationResolution() {
		return getImpl().getEvaluationResolution();
	}

	public void setEvaluationResolution(int resolution) {
		getImpl().setEvaluationResolution(resolution);
	}

}
